pub enum GgufError {
Nul(NulError),
InvalidPath,
Init(PathBuf),
}Expand description
Errors returned when opening a GGUF file.
Variants
Nul(NulError)
The path contained an interior NUL byte and could not be converted to a C string.
InvalidPath
The path was not valid UTF-8 and could not be converted to a C string.
Init(PathBuf)
gguf_init_from_file returned null (missing file or not a valid GGUF).