pub enum ApplyChatTemplateError {
NulError(NulError),
FromUtf8Error(FromUtf8Error),
FfiError(i32),
}Expand description
Failed to apply a chat template (see LlamaModel::apply_chat_template).
Variants
NulError(NulError)
The string contained a null byte and thus could not be converted to a c string.
FromUtf8Error(FromUtf8Error)
The formatted prompt could not be converted to utf8.
FfiError(i32)
llama_chat_apply_template returned an error code.